@@ -58,6 +58,7 @@ class FilterRange(ttk.Frame):
             scroll_modifier=self.scroll_modifier,
             keep_trailing_zeros=True,
             decimal_digits=6,
+            rounding="down",
         )
         self.lower_entry.grid(column=1, row=0, sticky="new")
         self.upper_entry = NumericEntry(
@@ -67,12 +68,17 @@ class FilterRange(ttk.Frame):
             scroll_modifier=self.scroll_modifier,
             keep_trailing_zeros=True,
             decimal_digits=6,
+            rounding="up",
         )
         self.upper_entry.grid(column=1, row=1, sticky="new")
 
         b_filter = ttk.Button(self, text="Limit to...", command=self.filter_energy)
         b_filter.grid(column=0, row=2, columnspan=3, sticky="new")
 
+        # trigger action on Enter key press
+        self.lower_entry.bind("<Return>", self.filter_energy, "+")
+        self.upper_entry.bind("<Return>", self.filter_energy, "+")
+
         root = self.winfo_toplevel()
         # root.bind("<<KeptChanged>>", self.set_upper_and_lower, "+")
         root.bind("<<DataExtracted>>", self.set_upper_and_lower, "+")
@@ -133,7 +139,7 @@ class FilterRange(ttk.Frame):
             self.upper_entry.update(upper)
             self.units_var.set(units)
 
-    def filter_energy(self):
+    def filter_energy(self, _event=None):
         showing = self.proxy["show"]()
         energy = self.proxy["genre"]()
         factor = 1e-2 if showing == "populations" else 1
@@ -190,6 +196,10 @@ class FilterRMSD(ttk.Frame):
         button = ttk.Button(self, text="Filter similar", command=self._filter)
         button.grid(column=0, row=4, columnspan=3, sticky="nwe")
 
+        # trigger action on Enter key press
+        window_size.bind("<Return>", self._filter, "+")
+        threshold.bind("<Return>", self._filter, "+")
+
         self.winfo_toplevel().changer.register(
             [window_size, threshold, ignore_hydrogens, button], "energies"
         )
@@ -199,7 +209,7 @@ class FilterRMSD(ttk.Frame):
         return self.winfo_toplevel().tesliper
 
     @ThreadedMethod(progbar_msg="Finding similar conformers...")
-    def _filter(self):
+    def _filter(self, _event=None):
         self.tesliper.conformers.trim_rmsd(
             threshold=float(self.threshold.get()),
             window_size=float(self.window_size.get()),
@@ -269,6 +279,7 @@ class FilterEnergies(CollapsiblePane):
         self.energies_choice.bind("<<ComboboxSelected>>", self.on_energies_selected)
         root = self.winfo_toplevel()
         root.bind("<<DataExtracted>>", self.on_show_selected, "+")
+        root.bind("<<KeptChanged>>", self.on_show_selected, "+")
         root.changer.register([self.show_combo, self.energies_choice], "energies")
 
     @property
@@ -968,6 +979,9 @@ class CalculateSpectra(CollapsiblePane):
     def _draw(self, queue_, **kwargs):
         try:
             spc = queue_.get(0)  # data put to queue by self._calculate_spectra
+            if spc is None:
+                # invalid parameters for spectra calculation given, abort
+                return
             self.view.draw_spectra(spc, **kwargs)
             self.lastly_drawn_spectra = spc
         except queue.Empty:
@@ -1021,10 +1035,15 @@ class CalculateSpectra(CollapsiblePane):
 
     @ThreadedMethod(progbar_msg="Calculating...")
     def _calculate_spectra(self, spectra_name, option, mode):
-        spc = self._exec_calculate_spectra(
-            spectra_name=spectra_name,
-            conformer=option if mode == "single" else None,
-        )
+        try:
+            spc = self._exec_calculate_spectra(
+                spectra_name=spectra_name,
+                conformer=option if mode == "single" else None,
+            )
+        except ValueError as error:
+            # happens on invalid start/stop/step combination
+            logger.warning(error)
+            return
         if mode == "average":
             en_name = self.average.get_genre()
             spc = self.tesliper.get_averaged_spectrum(spectra_name, en_name)
